@@ -36,4 +36,4 @@ class Main:
 
 if __name__ == "__main__":
     main = Main()
-    main.run()
+    run = main.run()
